@@ -56,6 +56,12 @@ st.write('last reload',current, 'last tradedate:',lastTD)
 
 L = ['L1','L2','L3']
 
+print(current)
+print(current > start)
+print(current > noon_start)
+
+
+
 def out_df_items(df):
     df = df.round(2)
     date, time = df['trade_date'].values[0], df['time'].values[0]
@@ -66,7 +72,6 @@ def out_df_items(df):
 
 def swl_rs_valuation_all(level):
     table_name = f'swl_rs_valuation_{level}'
-    print(table_name)
     data = pd.read_sql_table(table_name, conn)
     st.text(f'申万行业相对强度和估值_{level}')
     st.dataframe(data,width=1400, height=900)
@@ -91,8 +96,9 @@ def swl_rs_valuation():
 
 def write_stock_RS_OH_MA():
     st.text('相对强度 ')
-    table_name='stock_RS_OH_MA' if  current < start else 'stock_RS_OH_MA_new'
-    
+    #table_name='stock_RS_OH_MA' if  current < start else 'stock_RS_OH_MA_new'
+    table_name = 'stock_RS_OH_MA_new' 
+    #st.write(table_name)
     cols = ['cn_name','code', 'close','pct_chg','OH',"OL","swl_L3", 'rs_10','rs_250']
     cols2= ['cn_name','code', 'close','pct_chg','ma20','ma250','rs_10','rs_250','OH',"OL","swl_L3"]
     try:
@@ -105,7 +111,7 @@ def write_stock_RS_OH_MA():
             df2 = data[0][cols]
             df2 = df2.dropna(axis=0,how='any')
             df2 = df2.sort_values(by='swl_L3')
-            code = st.text_input('Input stock code:','300146')
+            code = st.text_input('Input stock code:','600519')
             df1 = data[0][cols2]
             st.dataframe(df1[df1.code == code].T)
             st.write(data[1], data[2])
@@ -118,7 +124,7 @@ def write_stock_RS_OH_MA():
             df2 = df[cols]
             df2 = df2.dropna(axis=0,how='any')
             df2 = df2.sort_values(by='swl_L3')
-            code = st.text_input('Input stock code:','300146')
+            code = st.text_input('Input stock code:','600519')
             df1 = data[cols2]
             st.dataframe(df1[df1.code == code].T)
             #st.text('相对强度 all')
@@ -197,7 +203,15 @@ def other_info():
 def main():
     selects = st.sidebar.selectbox(
     "Menu:",
-    ( "stock_PRS", "stock_PRS_top",'swl','stock_fundamental','stock_infomation','other_info'))
+    ("swl", 
+        "stock_PRS",
+        "stock_PRS_top",
+    #    'stock_fundamental',
+        'stock_infomation',
+        'other_info'))
+    
+    if selects == 'stock_PRS':
+          write_stock_RS_OH_MA()   
 
     if selects == 'swl':
         swl_rs_valuation()
@@ -212,4 +226,7 @@ def main():
 
 
 if __name__ == "__main__":
+    
     main()
+    pass
+
